Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(506)

Unified Diff: media/video/capture/screen/differ.h

Issue 13983010: Use webrtc::DesktopCapturer for screen capturer implementation. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/video/capture/screen/DEPS ('k') | media/video/capture/screen/differ.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/video/capture/screen/differ.h
diff --git a/media/video/capture/screen/differ.h b/media/video/capture/screen/differ.h
index 0ef3cc6fae6a6fbd3faf84241663b1f1bf610eb7..1676ecbd899c58f3831517e1d2cfb4e231870f51 100644
--- a/media/video/capture/screen/differ.h
+++ b/media/video/capture/screen/differ.h
@@ -10,13 +10,13 @@
#include "base/basictypes.h"
#include "base/memory/scoped_ptr.h"
#include "media/base/media_export.h"
-#include "third_party/skia/include/core/SkRegion.h"
+#include "third_party/webrtc/modules/desktop_capture/desktop_region.h"
namespace media {
typedef uint8 DiffInfo;
// TODO: Simplify differ now that we are working with SkRegions.
// diff_info_ should no longer be needed, as we can put our data directly into
// the region that we are calculating.
// http://crbug.com/92379
@@ -37,7 +37,7 @@ class MEDIA_EXPORT Differ {
// Given the previous and current screen buffer, calculate the dirty region
// that encloses all of the changed pixels in the new screen.
void CalcDirtyRegion(const void* prev_buffer, const void* curr_buffer,
- SkRegion* region);
+ webrtc::DesktopRegion* region);
private:
// Allow tests to access our private parts.
@@ -49,7 +49,7 @@ class MEDIA_EXPORT Differ {
// After the dirty blocks have been identified, this routine merges adjacent
// blocks into a region.
// The goal is to minimize the region that covers the dirty blocks.
- void MergeBlocks(SkRegion* region);
+ void MergeBlocks(webrtc::DesktopRegion* region);
// Check for diffs in upper-left portion of the block. The size of the portion
// to check is specified by the |width| and |height| values.
« no previous file with comments | « media/video/capture/screen/DEPS ('k') | media/video/capture/screen/differ.cc » ('j') | no next file with comments »
@@ -10,13 +10,13 @@
namespace media {
typedef uint8 DiffInfo;
-// TODO: Simplify differ now that we are working with SkRegions.
+// TODO: Simplify differ now that we are working with webrtc::DesktopRegion.
// diff_info_ should no longer be needed, as we can put our data directly into
// the region that we are calculating.

Powered by Google App Engine
This is Rietveld 408576698